@@ -1,7 +1,6 @@
 from . import core
 import json
-import yaml
-
+from cfn_flip import yaml
 
 def generate_from_json(template_content, name):
     result = core.generate(json.loads(template_content), name)
@@ -9,5 +8,5 @@ def generate_from_json(template_content, name):
 
 
 def generate_from_yaml(template_content, name):
-    result = core.generate(yaml.safe_load(template_content), name)
+    result = core.generate(yaml.load_yaml(template_content), name)
     return result
